@@ -92,7 +92,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Generator, List, TYPE_CHECKING
+from typing import Iterator, List, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_ssm.type_defs import (
     AssociationExecutionFilterTypeDef,
@@ -219,7 +219,7 @@ class DescribeActivationsPaginator(Boto3Paginator):
         self,
         Filters: List[DescribeActivationsFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeActivationsResultTypeDef, None, None]:
+    ) -> Iterator[DescribeActivationsResultTypeDef]:
         """
         [DescribeActivations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribeActivations.paginate)
         """
@@ -236,7 +236,7 @@ class DescribeAssociationExecutionTargetsPaginator(Boto3Paginator):
         ExecutionId: str,
         Filters: List[AssociationExecutionTargetsFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeAssociationExecutionTargetsResultTypeDef, None, None]:
+    ) -> Iterator[DescribeAssociationExecutionTargetsResultTypeDef]:
         """
         [DescribeAssociationExecutionTargets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribeAssociationExecutionTargets.paginate)
         """
@@ -252,7 +252,7 @@ class DescribeAssociationExecutionsPaginator(Boto3Paginator):
         AssociationId: str,
         Filters: List[AssociationExecutionFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeAssociationExecutionsResultTypeDef, None, None]:
+    ) -> Iterator[DescribeAssociationExecutionsResultTypeDef]:
         """
         [DescribeAssociationExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribeAssociationExecutions.paginate)
         """
@@ -267,7 +267,7 @@ class DescribeAutomationExecutionsPaginator(Boto3Paginator):
         self,
         Filters: List[AutomationExecutionFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeAutomationExecutionsResultTypeDef, None, None]:
+    ) -> Iterator[DescribeAutomationExecutionsResultTypeDef]:
         """
         [DescribeAutomationExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribeAutomationExecutions.paginate)
         """
@@ -284,7 +284,7 @@ class DescribeAutomationStepExecutionsPaginator(Boto3Paginator):
         Filters: List[StepExecutionFilterTypeDef] = None,
         ReverseOrder: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeAutomationStepExecutionsResultTypeDef, None, None]:
+    ) -> Iterator[DescribeAutomationStepExecutionsResultTypeDef]:
         """
         [DescribeAutomationStepExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribeAutomationStepExecutions.paginate)
         """
@@ -299,7 +299,7 @@ class DescribeAvailablePatchesPaginator(Boto3Paginator):
         self,
         Filters: List[PatchOrchestratorFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeAvailablePatchesResultTypeDef, None, None]:
+    ) -> Iterator[DescribeAvailablePatchesResultTypeDef]:
         """
         [DescribeAvailablePatches.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribeAvailablePatches.paginate)
         """
@@ -312,7 +312,7 @@ class DescribeEffectiveInstanceAssociationsPaginator(Boto3Paginator):
 
     def paginate(
         self, InstanceId: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[DescribeEffectiveInstanceAssociationsResultTypeDef, None, None]:
+    ) -> Iterator[DescribeEffectiveInstanceAssociationsResultTypeDef]:
         """
         [DescribeEffectiveInstanceAssociations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribeEffectiveInstanceAssociations.paginate)
         """
@@ -325,7 +325,7 @@ class DescribeEffectivePatchesForPatchBaselinePaginator(Boto3Paginator):
 
     def paginate(
         self, BaselineId: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[DescribeEffectivePatchesForPatchBaselineResultTypeDef, None, None]:
+    ) -> Iterator[DescribeEffectivePatchesForPatchBaselineResultTypeDef]:
         """
         [DescribeEffectivePatchesForPatchBaseline.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribeEffectivePatchesForPatchBaseline.paginate)
         """
@@ -338,7 +338,7 @@ class DescribeInstanceAssociationsStatusPaginator(Boto3Paginator):
 
     def paginate(
         self, InstanceId: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[DescribeInstanceAssociationsStatusResultTypeDef, None, None]:
+    ) -> Iterator[DescribeInstanceAssociationsStatusResultTypeDef]:
         """
         [DescribeInstanceAssociationsStatus.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribeInstanceAssociationsStatus.paginate)
         """
@@ -354,7 +354,7 @@ class DescribeInstanceInformationPaginator(Boto3Paginator):
         InstanceInformationFilterList: List[InstanceInformationFilterTypeDef] = None,
         Filters: List[InstanceInformationStringFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeInstanceInformationResultTypeDef, None, None]:
+    ) -> Iterator[DescribeInstanceInformationResultTypeDef]:
         """
         [DescribeInstanceInformation.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribeInstanceInformation.paginate)
         """
@@ -367,7 +367,7 @@ class DescribeInstancePatchStatesPaginator(Boto3Paginator):
 
     def paginate(
         self, InstanceIds: List[str], PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[DescribeInstancePatchStatesResultTypeDef, None, None]:
+    ) -> Iterator[DescribeInstancePatchStatesResultTypeDef]:
         """
         [DescribeInstancePatchStates.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribeInstancePatchStates.paginate)
         """
@@ -383,7 +383,7 @@ class DescribeInstancePatchStatesForPatchGroupPaginator(Boto3Paginator):
         PatchGroup: str,
         Filters: List[InstancePatchStateFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeInstancePatchStatesForPatchGroupResultTypeDef, None, None]:
+    ) -> Iterator[DescribeInstancePatchStatesForPatchGroupResultTypeDef]:
         """
         [DescribeInstancePatchStatesForPatchGroup.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribeInstancePatchStatesForPatchGroup.paginate)
         """
@@ -399,7 +399,7 @@ class DescribeInstancePatchesPaginator(Boto3Paginator):
         InstanceId: str,
         Filters: List[PatchOrchestratorFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeInstancePatchesResultTypeDef, None, None]:
+    ) -> Iterator[DescribeInstancePatchesResultTypeDef]:
         """
         [DescribeInstancePatches.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribeInstancePatches.paginate)
         """
@@ -412,7 +412,7 @@ class DescribeInventoryDeletionsPaginator(Boto3Paginator):
 
     def paginate(
         self, DeletionId: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[DescribeInventoryDeletionsResultTypeDef, None, None]:
+    ) -> Iterator[DescribeInventoryDeletionsResultTypeDef]:
         """
         [DescribeInventoryDeletions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribeInventoryDeletions.paginate)
         """
@@ -429,7 +429,7 @@ class DescribeMaintenanceWindowExecutionTaskInvocationsPaginator(Boto3Paginator)
         TaskId: str,
         Filters: List[MaintenanceWindowFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeMaintenanceWindowExecutionTaskInvocationsResultTypeDef, None, None]:
+    ) -> Iterator[DescribeMaintenanceWindowExecutionTaskInvocationsResultTypeDef]:
         """
         [DescribeMaintenanceWindowExecutionTaskInvocations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribeMaintenanceWindowExecutionTaskInvocations.paginate)
         """
@@ -445,7 +445,7 @@ class DescribeMaintenanceWindowExecutionTasksPaginator(Boto3Paginator):
         WindowExecutionId: str,
         Filters: List[MaintenanceWindowFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeMaintenanceWindowExecutionTasksResultTypeDef, None, None]:
+    ) -> Iterator[DescribeMaintenanceWindowExecutionTasksResultTypeDef]:
         """
         [DescribeMaintenanceWindowExecutionTasks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribeMaintenanceWindowExecutionTasks.paginate)
         """
@@ -461,7 +461,7 @@ class DescribeMaintenanceWindowExecutionsPaginator(Boto3Paginator):
         WindowId: str,
         Filters: List[MaintenanceWindowFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeMaintenanceWindowExecutionsResultTypeDef, None, None]:
+    ) -> Iterator[DescribeMaintenanceWindowExecutionsResultTypeDef]:
         """
         [DescribeMaintenanceWindowExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribeMaintenanceWindowExecutions.paginate)
         """
@@ -479,7 +479,7 @@ class DescribeMaintenanceWindowSchedulePaginator(Boto3Paginator):
         ResourceType: Literal["INSTANCE", "RESOURCE_GROUP"] = None,
         Filters: List[PatchOrchestratorFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeMaintenanceWindowScheduleResultTypeDef, None, None]:
+    ) -> Iterator[DescribeMaintenanceWindowScheduleResultTypeDef]:
         """
         [DescribeMaintenanceWindowSchedule.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribeMaintenanceWindowSchedule.paginate)
         """
@@ -495,7 +495,7 @@ class DescribeMaintenanceWindowTargetsPaginator(Boto3Paginator):
         WindowId: str,
         Filters: List[MaintenanceWindowFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeMaintenanceWindowTargetsResultTypeDef, None, None]:
+    ) -> Iterator[DescribeMaintenanceWindowTargetsResultTypeDef]:
         """
         [DescribeMaintenanceWindowTargets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribeMaintenanceWindowTargets.paginate)
         """
@@ -511,7 +511,7 @@ class DescribeMaintenanceWindowTasksPaginator(Boto3Paginator):
         WindowId: str,
         Filters: List[MaintenanceWindowFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeMaintenanceWindowTasksResultTypeDef, None, None]:
+    ) -> Iterator[DescribeMaintenanceWindowTasksResultTypeDef]:
         """
         [DescribeMaintenanceWindowTasks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribeMaintenanceWindowTasks.paginate)
         """
@@ -526,7 +526,7 @@ class DescribeMaintenanceWindowsPaginator(Boto3Paginator):
         self,
         Filters: List[MaintenanceWindowFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeMaintenanceWindowsResultTypeDef, None, None]:
+    ) -> Iterator[DescribeMaintenanceWindowsResultTypeDef]:
         """
         [DescribeMaintenanceWindows.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribeMaintenanceWindows.paginate)
         """
@@ -542,7 +542,7 @@ class DescribeMaintenanceWindowsForTargetPaginator(Boto3Paginator):
         Targets: List[TargetTypeDef],
         ResourceType: Literal["INSTANCE", "RESOURCE_GROUP"],
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeMaintenanceWindowsForTargetResultTypeDef, None, None]:
+    ) -> Iterator[DescribeMaintenanceWindowsForTargetResultTypeDef]:
         """
         [DescribeMaintenanceWindowsForTarget.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribeMaintenanceWindowsForTarget.paginate)
         """
@@ -558,7 +558,7 @@ class DescribeParametersPaginator(Boto3Paginator):
         Filters: List[ParametersFilterTypeDef] = None,
         ParameterFilters: List[ParameterStringFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeParametersResultTypeDef, None, None]:
+    ) -> Iterator[DescribeParametersResultTypeDef]:
         """
         [DescribeParameters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribeParameters.paginate)
         """
@@ -573,7 +573,7 @@ class DescribePatchBaselinesPaginator(Boto3Paginator):
         self,
         Filters: List[PatchOrchestratorFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribePatchBaselinesResultTypeDef, None, None]:
+    ) -> Iterator[DescribePatchBaselinesResultTypeDef]:
         """
         [DescribePatchBaselines.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribePatchBaselines.paginate)
         """
@@ -588,7 +588,7 @@ class DescribePatchGroupsPaginator(Boto3Paginator):
         self,
         Filters: List[PatchOrchestratorFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribePatchGroupsResultTypeDef, None, None]:
+    ) -> Iterator[DescribePatchGroupsResultTypeDef]:
         """
         [DescribePatchGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribePatchGroups.paginate)
         """
@@ -604,7 +604,7 @@ class DescribeSessionsPaginator(Boto3Paginator):
         State: Literal["Active", "History"],
         Filters: List[SessionFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeSessionsResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeSessionsResponseTypeDef]:
         """
         [DescribeSessions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.DescribeSessions.paginate)
         """
@@ -621,7 +621,7 @@ class GetInventoryPaginator(Boto3Paginator):
         Aggregators: List[InventoryAggregatorTypeDef] = None,
         ResultAttributes: List[ResultAttributeTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[GetInventoryResultTypeDef, None, None]:
+    ) -> Iterator[GetInventoryResultTypeDef]:
         """
         [GetInventory.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.GetInventory.paginate)
         """
@@ -638,7 +638,7 @@ class GetInventorySchemaPaginator(Boto3Paginator):
         Aggregator: bool = None,
         SubType: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[GetInventorySchemaResultTypeDef, None, None]:
+    ) -> Iterator[GetInventorySchemaResultTypeDef]:
         """
         [GetInventorySchema.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.GetInventorySchema.paginate)
         """
@@ -654,7 +654,7 @@ class GetParameterHistoryPaginator(Boto3Paginator):
         Name: str,
         WithDecryption: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[GetParameterHistoryResultTypeDef, None, None]:
+    ) -> Iterator[GetParameterHistoryResultTypeDef]:
         """
         [GetParameterHistory.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.GetParameterHistory.paginate)
         """
@@ -672,7 +672,7 @@ class GetParametersByPathPaginator(Boto3Paginator):
         ParameterFilters: List[ParameterStringFilterTypeDef] = None,
         WithDecryption: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[GetParametersByPathResultTypeDef, None, None]:
+    ) -> Iterator[GetParametersByPathResultTypeDef]:
         """
         [GetParametersByPath.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.GetParametersByPath.paginate)
         """
@@ -685,7 +685,7 @@ class ListAssociationVersionsPaginator(Boto3Paginator):
 
     def paginate(
         self, AssociationId: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListAssociationVersionsResultTypeDef, None, None]:
+    ) -> Iterator[ListAssociationVersionsResultTypeDef]:
         """
         [ListAssociationVersions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.ListAssociationVersions.paginate)
         """
@@ -700,7 +700,7 @@ class ListAssociationsPaginator(Boto3Paginator):
         self,
         AssociationFilterList: List[AssociationFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListAssociationsResultTypeDef, None, None]:
+    ) -> Iterator[ListAssociationsResultTypeDef]:
         """
         [ListAssociations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.ListAssociations.paginate)
         """
@@ -718,7 +718,7 @@ class ListCommandInvocationsPaginator(Boto3Paginator):
         Filters: List[CommandFilterTypeDef] = None,
         Details: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListCommandInvocationsResultTypeDef, None, None]:
+    ) -> Iterator[ListCommandInvocationsResultTypeDef]:
         """
         [ListCommandInvocations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.ListCommandInvocations.paginate)
         """
@@ -735,7 +735,7 @@ class ListCommandsPaginator(Boto3Paginator):
         InstanceId: str = None,
         Filters: List[CommandFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListCommandsResultTypeDef, None, None]:
+    ) -> Iterator[ListCommandsResultTypeDef]:
         """
         [ListCommands.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.ListCommands.paginate)
         """
@@ -752,7 +752,7 @@ class ListComplianceItemsPaginator(Boto3Paginator):
         ResourceIds: List[str] = None,
         ResourceTypes: List[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListComplianceItemsResultTypeDef, None, None]:
+    ) -> Iterator[ListComplianceItemsResultTypeDef]:
         """
         [ListComplianceItems.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.ListComplianceItems.paginate)
         """
@@ -767,7 +767,7 @@ class ListComplianceSummariesPaginator(Boto3Paginator):
         self,
         Filters: List[ComplianceStringFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListComplianceSummariesResultTypeDef, None, None]:
+    ) -> Iterator[ListComplianceSummariesResultTypeDef]:
         """
         [ListComplianceSummaries.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.ListComplianceSummaries.paginate)
         """
@@ -780,7 +780,7 @@ class ListDocumentVersionsPaginator(Boto3Paginator):
 
     def paginate(
         self, Name: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListDocumentVersionsResultTypeDef, None, None]:
+    ) -> Iterator[ListDocumentVersionsResultTypeDef]:
         """
         [ListDocumentVersions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.ListDocumentVersions.paginate)
         """
@@ -796,7 +796,7 @@ class ListDocumentsPaginator(Boto3Paginator):
         DocumentFilterList: List[DocumentFilterTypeDef] = None,
         Filters: List[DocumentKeyValuesFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListDocumentsResultTypeDef, None, None]:
+    ) -> Iterator[ListDocumentsResultTypeDef]:
         """
         [ListDocuments.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.ListDocuments.paginate)
         """
@@ -811,7 +811,7 @@ class ListResourceComplianceSummariesPaginator(Boto3Paginator):
         self,
         Filters: List[ComplianceStringFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListResourceComplianceSummariesResultTypeDef, None, None]:
+    ) -> Iterator[ListResourceComplianceSummariesResultTypeDef]:
         """
         [ListResourceComplianceSummaries.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.ListResourceComplianceSummaries.paginate)
         """
@@ -824,7 +824,7 @@ class ListResourceDataSyncPaginator(Boto3Paginator):
 
     def paginate(
         self, SyncType: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListResourceDataSyncResultTypeDef, None, None]:
+    ) -> Iterator[ListResourceDataSyncResultTypeDef]:
         """
         [ListResourceDataSync.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ssm.html#SSM.Paginator.ListResourceDataSync.paginate)
         """
